'''
Author: BHM-Bob 2262029386@qq.com
Date: 2022-11-01 22:16:49
LastEditors: BHM-Bob 2262029386@qq.com
LastEditTime: 2025-04-02 09:49:10
Description: 
'''

__title__ = "mbapy"
__description__ = "MyBA in Python"
__url__ = "https://github.com/BHM-Bob/BA_PY"
__version__ = "0.11.4"
__build__ = "20250806_1"
__author__ = "BHM-Bob G"
__author_email__ = "bhmfly@foxmail.com"
__license__ = "MIT"